<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>MIMIC Explorer</title>
    {% load static %}
    <link rel="stylesheet" href="{% static 'frontend/assets/index.css' %}">
</head>
<body>
    <div id="root"></div>
    <script src="{% static 'frontend/assets/index.js' %}"></script>
</body>
</html>
